import pandas as pd
import xlwings as xl
import pathlib as pl

rt = pl.WindowsPath(r'C:\Users\kevin.omalley\OneDrive - University of Limerick\Teaching\PS4041-2021(2)\Assignments\Assignment 2\Assignment 2 Due 6th December')

rts = [e for e in rt.iterdir() if '.xlsx'  in e.name]



for i in rts:
    print(i)

del rts[1]
del rts[2]
print('deleting unneeded')


for i in rts:
    print(i)

df = pd.DataFrame()

for f in rts:
    data=pd.read_excel(f)
    df = df.append(data)

#df.to_excel(r'C:\Users\kevin.omalley\OneDrive - University of Limerick\Teaching\PS4041-2021(2)\Assignments\Assignment 2\Assignment 2 Due 6th December\recollected.xlsx', index = False)




import pathlib as pl 
import pandas as pd 
import xlwings as xl

#importing the main grades file. 
d = pl.WindowsPath(r'C:\Users\kevin.omalley\OneDrive - University of Limerick\Documents\GitHub\grading_colation\data\Assignment 2 Due 6th December')
if 'grades.xls' in [i.name for i in d.iterdir()]:
    df = pd.read_excel(d/'grades.xls', header = 0, usecols='A:G')
    df['Grader'] = ''
    df['Comments'] = ''

sn = df.shape[0] # the number of students in the grades sheet.
print(sn)

graders = ['Kev', 'Ryan', 'Aoife', 'Muireann', 'Joe'] #list of graders names
frames = dict.fromkeys(graders, pd.DataFrame())

sg = int(len(graders)) #number of graders
print(sg)

split = sn//sg # the amount of papers each grader gets if evenly distributed

# if sn % sg ==0: # noting what the distribution of papers would be, with leftovers listed if needed. 
#     print(f'Each TA can take {split}')
# else:
#     print(f'Each TA can take {split}, with {sn % sg} left over')



for i in df.index:
    print(i)


'''
Created by Kev 'Sp1d3r-Z3r0' O'Malley (kevin.omalley[@]ul.ie, Github = 'https://github.com/spider-z3r0'), 19/07/2021, as part of the ULpsych grader bot package.

Contains a function that check if the user has downloaded the submissions from sulis and returns the directory address as a Path object and a unicode-escaped string.
'''
from pathlib import Path 

def sulis_check():
    while True: #taking the first input to identify the Sulis download.
        su_download_check = input("\nHave you downloaded the student submissions from sulis? \n('y' = yes, 'n' = no, type = 'exit' if you wish to close the program)\n")

        if str.lower(su_download_check) == 'y':#if the user states that they have downloaded the submissions from sulis
            su_download_address = input('Excellent, please enter the *full* folder location of the sulis download\n')# taking the string version of the submissions directory
            su_download_address.encode('unicode_escape')# turning that string into a raw string so that it can be used in Path
            su_download_path = Path(su_download_address)# making directory into a Path Object

            if su_download_path.exists():# If the directory actually exists (i.e. if actually downloaded and entered into the terminal correctly)
                print(f"You have selected '{str(su_download_address)}' as the folder containing the student records.") # confirming the address
                return(su_download_address, su_download_path)# returning both the Path and Raw-string objects.
            else:
                print("Sorry, I can't find that file, please check the folder address and try again")# telling the user they can't find the file and making a suggestion
                pass
        elif str.lower(su_download_check) == 'n': # if the download hasn't happened yet
            print("OK, please go the assignment tab on the Sulis module and download *all* submissions. When you have done this come back and we'll start again.")
            exit()#closing the program altogether
        elif str.lower(su_download_check) == 'exit':#if the user decides to close the program and not progress
            print("OK, I'll be here when you're ready to start again.")
            exit()#closing the program altogether
        else:
            print("I don't understand your input. Please type 'y' or 'n' only.")
            pass
    



import pandas as pd
import numpy as np

#making the df
df = pd.DataFrame()
df['ids'] = np.random.randint(1, 140, size=140)
df['group_leader'] = ''


# list of leader names
leaders = ['John', 'Paul', 'George', 'Ringo', 'Apu']

frames = dict.fromkeys('group_leaders', pd.DataFrame())

for i in frames.keys(): #allows me to fill the cells with the string key?
    df.loc[df.sample(n=28).index, 'group_leader'] = str(i)
    frames[i].update(df[df['group_leader']== str(i)].copy())#also tried append()
    print(frames[i].head())
    df = df[df['group_leader'] != str(i)]
    print(f'df now has {df.shape[0]} ids left') #just in case there's a remainder of ids


import pandas as pd
import pathlib as pl
import xlwings as xl

s = pl.WindowsPath(r'C:\Users\kevin.omalley\OneDrive - University of Limerick\Teaching\PS4041-2021(2)\Assignments\Assignment 2\Assignment 2 Due 6th December\grades.xls')
r = pl.WindowsPath(r'C:\Users\kevin.omalley\OneDrive - University of Limerick\Teaching\PS4041-2021(2)\Assignments\Assignment 2\Assignment 2 Due 6th December\recollected.xlsx')


dfs = pd.read_excel(s, header = 0, usecols = 'A:G')
dfr = pd.read_excel(r, header = 0, usecols = 'A:H')

dfs.to



from pathlib import Path
import shutil as shu
import dateparser as dtp


class Document:
    '''A class for module documents like
    handbooks, assignment briefs, etc.'''
    def __init__(self, name, doc_type):
        self.name = name
        self.doc_type = doc_type


    def find_document(self):
        ''' Check if there is an existing document that can be copied into place'''

    
    


    




# a = r'C:\Users\kevin.omalley\Desktop\Hero influence scale abstract.docx'
# b = r'C:\Users\kevin.omalley\Documents\GitHub\grading_colation\data\test'
# test = Document('Assignment 1 brief', a, )
# print(test.location)
# test.copyDocument(b)



import pandas as pd
import pathlib as pl
from shutil import copy

add = input('Address please!')
add.encode('unicode_escape')

folder = pl.Path(add)

recs = [e.name for e in folder.iterdir()]

for (i,file) in enumerate(recs):
    print(f'{i}: {file}')

choice = input('Please select the folder containing the student records \n(press "n" to cancel)')

if int(choice) <=  len(recs):
    sub_folder = folder / recs[int(choice)]
    print(f'You have selected {sub_folder}')
    j = [e.name for e in sub_folder.iterdir()]
    for i in j:
        print(f'{i}\n')
    
elif choice == 'n': 
    print("No choice made, ending process. Please rerun file")
    quit()
    
    


''' Created by Kevin O'Malley, July 18 2021.
This file should hold the code for setting up the folder structure creating the module at the start of a semester. It will take the downloaded submissions from and create a "workspace"
for storing and working with the student files. Over time I hope to add functionality that will make creating extrn packs easier, faster and less bias prone.
'''

from pathlib import Path
from shutil import move


print("let's make a module")


class Module:
    '''A class that allows us to work with teaching modules'''

    def __init__(self, name, code, year, location):
        self.name = name
        self.code = code
        self.year = year
        self.location = location



    def module_setup(self):
        '''Method for setting up the module folder structure'''
        check_coursework = input("Does this module require students to submit coursework assignments?('y' = yes, 'n' = no)\n")
        check_exams = input("Does this module have an end of semester exam?('y' = yes, 'n' = no)\n")
        count_lessons = input('Please enter the number teaching weeks for this module (positive intergers only please)\n')
        lessons_count = int(count_lessons)

        while True:
            if str.lower(check_coursework) == 'y':
                count_coursework = input('Please enter the number of coursework assignments for this module (positive intergers only please)\n')
                coursework_number = int(count_coursework)
                print(f'OK {int(count_coursework)} coursework assignments\n')
                break
            elif str.lower(check_coursework) == 'n':
                print('OK no coursework')
                break
            else:
                print('Sorry I do not understand.')
                continue
        
        
        while True:
            if str.lower(check_exams) == 'y':
                print(f'OK, this module has an exam.')
                break
            elif str.lower(check_exams) == 'n':
                print('OK no end of semester exam')
                break
            else:
                print('Sorry I do not understand.')
                continue
        module_path_string = f'{self.location}\{self.code}-{self.year}'
        set_up_check = input(f"Would you like to set up a home folder and subfolders for this module at {module_path_string}?('y' = yes, 'n' = no)\n")
        
        while True:
            if str.lower(set_up_check) == 'y':
                print(f'OK, creating folder at {module_path_string}...')
                
                if Path(module_path_string).exists():
                    print(f"I'm sorry, the folder {module_path_string} already exists, please check the folder at that location.")
                    exit()
                else:
                    assignments = Path(module_path_string) / 'Assignments'
                    documents = Path(module_path_string) / 'Module Documents'
                    exams = Path(module_path_string) / 'Exam'


                    lessons = Path(module_path_string) / 'Lesson Materials'

                    Path(module_path_string).mkdir(parents=True, exist_ok=False)
                    documents.mkdir(parents=True, exist_ok=False)
                    assignments.mkdir(parents=True, exist_ok=False)
                    lessons.mkdir(parents=True, exist_ok=False)

                    for i in range(1,coursework_number+1):
                        sub_assignment = assignments / f'Assignment {i}'
                        sub_assignment.mkdir(parents=True, exist_ok=False)
                    for i in range(1,lessons_count+1):
                        lesson = lessons / f'Teaching week {i}'
                        lesson.mkdir(parents=True, exist_ok=False)
                    
                    if check_exams == 'y':
                        exams.mkdir(parents=True, exist_ok=False)

                    
                break
            elif str.lower(set_up_check) == 'n':
                print('OK, you can create your own folder structure, or restart this function if you wish to change details')
                break
            else:
                print('Sorry I do not understand.')
                break
        print(f'OK I have created the folder {module_path_string}. This contains the sub-folders: {[x.name for x in Path(module_path_string).iterdir()]}\n')
        return(Path(module_path_string))#Maybe you can return more objects or maybe you can be more granular? Or different versions of the function depending on the usecase? 




        







'''
Created by Kev 'Sp1d3r-Z3r0' O'Malley (kevin.omalley[@]ul.ie, Github = 'https://github.com/spider-z3r0'), 19/07/2021, as part of the ULpsych grader bot package.
Contains a function that 
1: checks if the user wants to move the submission sub-directories to a new directory
2: checks if the target directory already exists
3: creates the target directory if it doesn't
4: or leaves the submission sub-directories in thier original location if the user prefers  
'''

from pathlib import Path
from shutil import move




def move_submissions(a):
    while True:
        move_check = input('''
        Would you like to move the submission from thier current location to a new directory\n('y' = yes, 'n' = no, type = 'exit' if you wish to close the program)\n
        ''')
        if str.lower(move_check) == 'y':
            w_space_input = input("OK, please type the location where you would like me to move the student submissions")
            w_space_input.encode('unicode escape')
            w_space_directory = Path(w_space_input)
            if not w_space_directory.exists():
                print("The location you have specified doesn't exist, would you likye me to make it for you?\n")
                create_w_space = input("('y' = yes, 'n' = no, 'exit' = you wish to close the program)\n")
                if str.lower(create_w_space) == 'y':
                    w_space_directory.mkdir(parents=True, exist_ok=False)
                    move(a, w_space_input)
                    return(move_check, w_space_directory)
                    break
            else:
                print("OK, I'm moving the student submissions to '{w_space_input}'now\n")
                move(a, w_space_input)
                print("\nFolders moved")
                return(move_check, w_space_directory)
                break
        else:
            print(f"OK we can leave them where them in '{a}' for now")
            return(move_check, a)
            break
        



from shutil import move
from sulis_check import sulis_check
from move_submissions import move_submissions
from create_workspace import set_up




sulis_check('C:\Users\kevin.omalley\Documents\GitHub\grading_colation\data\student submissions')

move_submissions()




import pandas as pd
import xlwings as xl
import pathlib as pl


# file = pl.WindowsPath(r'C:\Users\kevin.omalley\OneDrive - University of Limerick\Teaching\PS4041-2021(2)\Assignments\Assignment 2\Assignment 2 Due 6th December\grades.xls')

df = pd.read_excel(file)

graders = ['Kev', '', 'Ryan', '', 'Joe']



df['Grader'] = ''
df.loc[df.sample(n=30).index, 'Grader'] = 'Ryan'
r = df[df['Grader']=='Ryan'].copy()
r.to_csv(r'C:\Users\kevin.omalley\OneDrive - University of Limerick\Teaching\PS4041-2021(2)\Assignments\Assignment 2\Assignment 2 Due 6th December\ryan.csv', index = False)
df = df[df.Grader != 'Ryan']

df.loc[df.sample(n=25).index, 'Grader'] = 'Muirean'
m = df[df['Grader']=='Muirean'].copy()
m.to_csv(r'C:\Users\kevin.omalley\OneDrive - University of Limerick\Teaching\PS4041-2021(2)\Assignments\Assignment 2\Assignment 2 Due 6th December\Muirean.csv', index = False)
df = df[df.Grader != 'Muirean']

df.loc[df.sample(n=25).index, 'Grader'] = 'Aoife'
a = df[df['Grader']=='Aoife'].copy()
a.to_csv(r'C:\Users\kevin.omalley\OneDrive - University of Limerick\Teaching\PS4041-2021(2)\Assignments\Assignment 2\Assignment 2 Due 6th December\Aoife.csv', index = False)
df = df[df.Grader != 'Aoife']

df.loc[df.sample(n=10).index, 'Grader'] = 'Joe'
j = df[df['Grader']=='Joe'].copy()
j.to_csv(r'C:\Users\kevin.omalley\OneDrive - University of Limerick\Teaching\PS4041-2021(2)\Assignments\Assignment 2\Assignment 2 Due 6th December\Joe.csv', index = False)
df = df[df.Grader != 'Joe']
df['Grader'] = 'Kev'
df.to_csv(r'C:\Users\kevin.omalley\OneDrive - University of Limerick\Teaching\PS4041-2021(2)\Assignments\Assignment 2\Assignment 2 Due 6th December\kev.csv', index = False)


combined = pd.concat([j,df,m,a,r])
print(len(combined))
print(len(r))
print(len(m))
print(len(a))
print(len(j))
print(len(df))


import pandas as pd
import xlwings as xl
import pathlib as pl
import pyperclip as pc




file = pl.WindowsPath(r'C:\Users\kevin.omalley\OneDrive - University of Limerick\Teaching\PS4041-2021(2)\Assignments\Assignment 2\Assignment 2 Due 6th December\grades.xls')

df = pd.read_excel(file)

def find_lates(frame):
    """Find the lats submissions and prepare the email addresses"""
    lates = frame[frame['Late submission']== 'Unknown'].copy()
    emails =[]
    for i in lates['Display ID']:
        emails.append(f'{i}@studentmail.ul.ie')
    def list_to_clipboard(output_list):
        """ Check if len(list) > 0, then copy to clipboard """
        if len(output_list) > 0:
            pc.copy('\n'.join(output_list))
            print(f'{output_list} Copied to clipboard: ')
        else:
            print("There was nothing on the clipboard")
    
    list_to_clipboard(emails)


find_lates(df)


'''This file is for taking all the completed grading sheets and moving them into the respective students records to be reuploaded to SULIS'''
import pathlib as pl
from shutil import copy

add = input('Address please!')
add.encode('unicode_escape')


rt = pl.Path(add)
dr = rt / 'student records'
gr = rt / 'grading sheets'

recs = [e.name for e in dr.iterdir()]

for folder in dr.iterdir():
    # We're only interested in folders
    if not folder.is_dir():
        continue

    target_file = f"{folder.name} grading sheet.xlsx"
    for file in gr.rglob(target_file):
        #copy(file, folder)
        print(f'{file.name} copied to {folder}')


''' Created by Kevin O'Malley, July 18 2021.
This file should hold the code for setting up the folder structure creating the module at the start of a semester. It will take the downloaded submissions from and create a "workspace"
for storing and working with the student files. Over time I hope to add functionality that will make creating extrn packs easier, faster and less bias prone.
'''

from pathlib import Path
from shutil import move




def module_setup():
    teaching_root_folder = input('Please copy and paste the full folder address of the folder where you store your teaching files\n')
    module_code = input('Please enter the module code for the class you are teaching (i.e. PS4000)\n')
    module_year = input('Please enter the accademic year for this module (i.e. 2021)\n')
    check_coursework = input("Does this module require students to submit coursework assignments?('y' = yes, 'n' = no)\n")
    
    while True:
        if str.lower(check_coursework) == 'y':
            count_coursework = input('Please enter the number of coursework assignments for this module (positive intergers only please)\n')
            coursework_number = int(count_coursework)
            print(f'OK {int(count_coursework)} coursework assignments\n')
            break
        elif str.lower(check_coursework) == 'n':
            print('OK no coursework')
            break
        else:
            print('Sorry I do not understand.')
            continue
    
    check_exams = input("Does this module have an end of semester exam?('y' = yes, 'n' = no)\n")
    
    while True:
        if str.lower(check_exams) == 'y':
            print(f'OK, this module has an exam.')
            break
        elif str.lower(check_exams) == 'n':
            print('OK no end of semester exam')
            break
        else:
            print('Sorry I do not understand.')
            continue
    module_path_string = f'{teaching_root_folder}\{module_code}-{module_year}'
    module_path_string.encode('unicode escape')
    set_up_check = input(f"Would you like to set up a home folder and subfolders for this module at {module_path_string}?('y' = yes, 'n' = no)\n")
    
    while True:
        if str.lower(set_up_check) == 'y':
            print(f'OK, creating folder at {module_path_string}...')
            
            if Path(module_path_string).exists():
                print(f"I'm sorry, the folder {module_path_string} already exists, please check the folder at that location.")
                exit()
            else:
                assignments = Path(module_path_string) / 'Assignments'
                documents = Path(module_path_string) / 'Module Documents'
                exams = Path(module_path_string) / 'Exam'
                Path(module_path_string).mkdir(parents=True, exist_ok=False)
                documents.mkdir(parents=True, exist_ok=False)
                assignments.mkdir(parents=True, exist_ok=False)

                for i in range(1,coursework_number+1):
                    sub_assignment = assignments / f'Assignment {i}'
                    sub_assignment.mkdir(parents=True, exist_ok=False)
                if check_exams == 'y':
                    exams.mkdir(parents=True, exist_ok=False)
            break
        elif str.lower(set_up_check) == 'n':
            print('OK, you can create your own folder structure, or restart this function if you wish to change details')
            break
        else:
            print('Sorry I do not understand.')
            continue
    print(f'OK I have created the folder {module_path_string}. This contains the sub-folders: {[x.name for x in Path(module_path_string).iterdir()]}\n')
    return(Path(module_path_string))#Maybe you can return more objects or maybe you can be more granular? Or different versions of the function depending on the usecase? 



class Document:
    '''A class for module documents like
    handbooks, assignment briefs, etc.'''
    def __init__(self, name, location, filetype, kind):
        self.name = name
        self.location = location
        self.filetype = filetype

    
    def makeDocument():
        n = input('please enter the name you would like to call the document')
        l = input('please enter the location of the document you would like to use')
        l.encode('unicode escape')
        l = Path(l)
        d = l.suffix
        i = Document(n, l, d)
        print(f'''I have found the document {l.name} in {l.parent}''')

    def copyDocument():
        l = input('please enter the location of the document you would like to use')
        l.encode('unicode escape')
        if Path(l).is_file():
            print('Found it')
        else:
            print('no file here')








'''This file is built to allow faculty to quickly generate records of student submission upon downloading them from sulis.'''

import pathlib as pl
import pandas as pd
from shutil import copy

dir_name = input('Please specify the folder address of the Sulis download')
dir_name.encode('unicode_escape')

main_directory = pl.Path(dir_name)
choices = [e.name for e in main_directory.iterdir()]

for (i,file) in enumerate(choices):
    print(f'{i}: {file}')


choice = input('Please select the folder containing the student records \n(press "n" to cancel)')


if int(choice) <=  len(choices):
    sub_folder = main_directory / choices[int(choice)]
    print(f'You have selected {sub_folder}')
    
elif choice == 'n': 
    print("No choice made, ending process. Please rerun file")
    quit()

students = [e.name for e in sub_folder.iterdir()]

df = pd.DataFrame({'col1':students})


df[['Last', 'First', 'Number']] = df.col1.str.split(r"\(|," , expand=True)
df['Number'] = df['Number'].str.rstrip(')')
df['Grader'] = ''
df['Mark'] = ''
df['Letter Grade'] = ''
df = df.drop(['col1'], axis = 1)

df.to_excel(main_directory / 'class list grading sheet.xlsx', index=False)

print(df.head()) 



'''Created by Kev O Malley August 7th 2021 
This will hold all code related to assignments. 
'''

from pathlib import Path
import pandas as pd
import numpy as np
import xlwings as xlw
import chardet as ch




class Assignment:
   '''A class that allows us to work with assignments''' 
   def __init__(self, location):
      try:   
         if Path(f'{location}').exists() or Path(f'{location}/ Assignments').exists():
            self.location = Path(location)     
         else:
            raise FileNotFoundError('No folder')
      except FileNotFoundError:
            print(f'''There is no assignments folder at {location} you can 
            1. check the spelling
            2. manually make the folder and try again
            3. run the module set_up function for this module *if you have not done so already*
            ''')
            pass

   def sulis_import(self, name, filetype = '.csv'):
      """This function imports the grades sheet once it has been downloaded from sulis"""
      if str.lower(filetype) == '.csv':
         t = self.location / str(name) / 'grades.csv'
         if t.exists():
            with open(t, 'rb') as f:
               enc = ch.detect(f.read())  # or readline if the file is large
            grades = pd.read_csv(t,skiprows = [0,1], encoding = enc['encoding'])
      elif str.lower(filetype) == '.xlsx':
         t = self.location / str(name) / 'grades.xlsx'
         if t.exists():
            grades = pd.read_excel(t)
      elif str.lower(filetype) ==  '.xls':
         t = self.location / str(name) / 'grades.xls'
         if t.exists():
            grades = pd.read_excel(t)
      return(grades)


   def prep_groups(self, df):
      '''This function is meant to take in groups sheets
      and structure the grades file so that groups can be assigned to a grader
      built with PS4034/6022 in mind but needs to expand. '''

   def distribute(self, graders, df):
      '''Take in the grades file and distribute
      students to the graders'''
      if type(graders) != list:
         print('Please give a list of grading assistant names')
      else:
         split = len(df)/len(graders)
         m_graders = np.repeat(graders, np.ceil(len(df) / len(graders)))
         np.random.shuffle(m_graders)
         df['grader'] = m_graders[:len(df)]
         for i in graders:
            s = df[df['grader'] == i]
            s.to_excel(Path(f'{self.location}/{i}.xlsx'), index=False)
         # This needs to be expanded to accomodate group assignments where people would be grouped together. 


         
         
         
      






'''
Created by Kev 'Sp1d3r-Z3r0' O'Malley (kevin.omalley[@]ul.ie, Github = 'https://github.com/spider-z3r0'), 19/07/2021, as part of the ULpsych grader bot package.

The aim of this module is to set up a workspace 'parent' directory which can be used to organise all the sub-directories for a particular assignment. I'm just going to play around
with this and see what happens. 
'''
from Module import module_setup

a = module_setup()


import os
from setuptools import setup

def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()

with open("README.md", "r") as fh:
    long_description =fh.read()

setup(
    name = "ulpsych",
    version = "0.0.0.1",
    author = "Kevin O'Malley",
    author_email = "kevin.omalley@ul.ie",
    description = ('''A tool for helping people with administration tasks, with a focus on grading admin and module setup'''),
    license = "GNU GPL",
    py_modules=['Module', 'Assignment', ],
    erl = "https://github.com/spider-z3r0/grading_colation",
    package_dir={'':'src'},
    long_description= long_description,
    long_description_content_type = 'text/markdown',
    extras_require = {
        "dev" :[
            "pytest>=3.7",
        ],
    },
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Topic :: Utilities",
    ],
)


import pathlib as pl
import os
from shutil import copy, move


print("S'all good homie")

over_dir = pl.WindowsPath(r'C:\Users\kevin.omalley\OneDrive - University of Limerick\Documents\GitHub\grading_colation\data\Submissions')
a = [e.name for e in over_dir.iterdir()]

for i in a:
    sub_dir = over_dir / str(i)
    fb = sub_dir / 'Feedback Attachment(s)'
    b = [e for e in sub_dir.iterdir()]
    for j in b:
        if '.xlsx' in j.name:
            move(j, fb)




'''Created by Kevin O'Malley 12/04/2022 
This holds the old Assignment function code incase it is needed in future.
'''



from pathlib import Path
import pandas as pd
from shutil import copy, move
import xlwings as xlw


class Assignment:
   '''A class that allows us to work with assignments''' 
   def __init__(self, location):
      try:   
         if Path(f'{location}').exists() or Path(f'{location}/ Assignments').exists():
            self.location = location         
         else:
            raise FileNotFoundError('No folder')
      except FileNotFoundError:
            print(f'''There is no assignments folder at {location} you can 
            1. check the spelling
            2. manually make the folder and try again
            3. run the module set_up function for this module *if you have not done so already*
            ''')
            pass

   def import_subs(self):
      """This function imports the submissions once they have been downloaded from sulis"""
      sub_dir = input('Please enter the location of the downloaded submissions: \n')
      sub_dir.encode('unicode escape')
      try:
         if Path(f'{sub_dir}').is_dir():
            move(sub_dir, self.location)
            e = Path(f'{Path(self.location)}/{Path(sub_dir).name}')
            e = e.rename(f'{self.location}\\submissions')
            print(f"\nSubmissions moved to: \n {str(e)}\n please verify the move by checking the assignment folder.\n")
            return(Path(e))
         else:
            raise FileNotFoundError('No folder')
      except FileNotFoundError:
         print("""There is no folder here, check the location you have enetered again""")
         pass

   def mk_grading_sheets(self):
      """This reads the submissions folder and takes the names of the students """
      students = [e.name for e in Path(f'{self.location}\submissions').iterdir()]
      df = pd.DataFrame({'col1':students})
      df[['Last', 'First', 'Number']] = df.col1.str.split(r"\(|," , expand=True)
      df['Number'] = df['Number'].str.rstrip(')')
      df['Grader'] = ''
      df['Mark'] = ''
      df['Letter Grade'] = ''
      df = df.drop(['col1'], axis = 1)

      df.to_excel(Path(f'{self.location}\\submissions\\class list grading sheet.xlsx'), index=False)